@@ -44,4 +44,15 @@ BASE_QUOTA_DEFAULT_URL = BASE_QUOTA_URL + '/defaults'
 
 BASE_AMPHORA_URL = BASE_OCTAVIA_ENDPOINT + "/amphorae"
 BASE_SINGLE_AMPHORA_URL = BASE_AMPHORA_URL + "/{uuid}"
+BASE_AMPHORA_CONFIGURE_URL = BASE_SINGLE_AMPHORA_URL + '/config'
 BASE_AMPHORA_FAILOVER_URL = BASE_SINGLE_AMPHORA_URL + '/failover'
+
+BASE_PROVIDER_URL = BASE_LBAAS_ENDPOINT + "/providers"
+BASE_PROVIDER_FLAVOR_CAPABILITY_URL = (BASE_LBAAS_ENDPOINT +
+                                       "/providers/{provider}/"
+                                       "flavor_capabilities")
+
+BASE_FLAVOR_URL = BASE_LBAAS_ENDPOINT + "/flavors"
+BASE_SINGLE_FLAVOR_URL = BASE_FLAVOR_URL + "/{uuid}"
+BASE_FLAVORPROFILE_URL = BASE_LBAAS_ENDPOINT + "/flavorprofiles"
+BASE_SINGLE_FLAVORPROFILE_URL = BASE_FLAVORPROFILE_URL + "/{uuid}"
